@@ -12,8 +12,7 @@
  *
  **********************************************************************/
 
-#ifndef GEOS_H
-#define GEOS_H
+#pragma once
 
 /*
  * \file geos.h
@@ -34,10 +33,7 @@
 #include <geos/io/WKTReader.h>
 #include <geos/io/WKTWriter.h>
 #include <geos/io/CLocalizer.h>
-#include <geos/unload.h>
 
 /// Basic namespace for all GEOS functionalities.
 namespace geos {
 }
-
-#endif
