@@ -17,11 +17,12 @@
  *
  **********************************************************************/
 
-#ifndef GEOS_GEOM_COORDINATELIST_H
-#define GEOS_GEOM_COORDINATELIST_H
+#pragma once
 
 #include <geos/export.h>
 #include <geos/geom/Coordinate.h>
+#include <geos/geom/CoordinateSequence.h>
+#include <geos/util.h>
 
 #include <list>
 #include <ostream> // for operator<<
@@ -45,7 +46,7 @@ namespace geom { // geos::geom
 
 /** \brief
  * A list of {@link Coordinate}s, which may
- * be set to prevent repeated coordinates from occuring in the list.
+ * be set to prevent repeated coordinates from occurring in the list.
  *
  * Use this class when fast insertions and removal at arbitrary
  * position is needed.
@@ -71,12 +72,18 @@ public:
      *
      * @param v the initial coordinates
      */
-    CoordinateList(const std::vector<Coordinate>& v)
+    template<typename T>
+    CoordinateList(const T& v)
         :
         coords(v.begin(), v.end())
     {
     }
 
+    CoordinateList(const CoordinateSequence& v)
+        : CoordinateList(v.items<Coordinate>())
+    {
+    }
+
     CoordinateList()
         :
         coords()
@@ -145,6 +152,12 @@ public:
         return coords.insert(pos, c);
     }
 
+    iterator
+    add(const Coordinate& c, bool allowRepeated)
+    {
+        return insert(coords.end(), c, allowRepeated);
+    }
+
     iterator
     insert(iterator pos, const Coordinate& c)
     {
@@ -170,6 +183,15 @@ public:
         ret->assign(coords.begin(), coords.end());
         return ret;
     }
+
+    std::unique_ptr<geom::CoordinateSequence>
+    toCoordinateSequence() const
+    {
+        auto ret = detail::make_unique<geom::CoordinateSequence>();
+        ret->add(begin(), end());
+        return ret;
+    }
+
     void
     closeRing()
     {
@@ -179,6 +201,14 @@ public:
         }
     }
 
+    static void
+    closeRing(std::vector<Coordinate>& coords)
+    {
+        if(!coords.empty() && !(*(coords.begin())).equals(*(coords.rbegin()))) {
+            const Coordinate& c = *(coords.begin());
+            coords.insert(coords.end(), c);
+        }
+    }
 
 private:
 
@@ -212,4 +242,3 @@ operator<< (std::ostream& os, const CoordinateList& cl)
 #pragma warning(pop)
 #endif
 
-#endif // ndef GEOS_GEOM_COORDINATELIST_H
