@@ -95,13 +95,27 @@ public:
      */
     void setOutputDimension(uint8_t newOutputDimension);
 
+    /*
+     * Sets whether the GeoJSON should be output following counter-clockwise orientation aka Right Hand Rule defined in
+     * RFC7946. See <a href="https://tools.ietf.org/html/rfc7946#section-3.1.6">RFC 7946 Specification</a>
+     * for more context.
+     *
+     * @param newIsForceCCW true if the GeoJSON should be output following the RFC7946
+     *                      counter-clockwise orientation aka Right Hand Rule
+     */
+    void setForceCCW(bool newIsForceCCW);
+
 private:
     uint8_t defaultOutputDimension = 3;
 
+    bool isForceCCW = false;
+
     std::vector<double> convertCoordinate(const geom::Coordinate* c);
 
     std::vector<std::vector<double>> convertCoordinateSequence(const geom::CoordinateSequence* c);
 
+    std::vector<std::vector<std::vector<double>>> convertLinearRings(const geom::Polygon *poly);
+
     void encode(const geom::Geometry* g, GeoJSONType type, geos_nlohmann::ordered_json& j);
 
     void encodeGeometry(const geom::Geometry* g, geos_nlohmann::ordered_json& j);
