@@ -43,8 +43,6 @@
 #pragma warning(disable : 4127)
 #endif
 
-using namespace std; // for isfinite..
-
 namespace geos {
 namespace algorithm { // geos.algorithm
 
@@ -54,10 +52,9 @@ RobustDeterminant::signOfDet2x2(double x1, double y1, double x2, double y2)
 {
     // returns -1 if the determinant is negative,
     // returns  1 if the determinant is positive,
-    // retunrs  0 if the determinant is null.
+    // returns  0 if the determinant is null.
     int sign = 1;
     double swap;
-    double k;
 
     // Protect against non-finite numbers
     if(!std::isfinite(x1) || !std::isfinite(y1) || !std::isfinite(x2) || !std::isfinite(y2)) {
@@ -216,7 +213,7 @@ RobustDeterminant::signOfDet2x2(double x1, double y1, double x2, double y2)
     *  all entries strictly positive   x1 <= x2 and y1 <= y2
     */
     while(true) {
-        k = std::floor(x2 / x1);
+        double k = std::floor(x2 / x1);
         x2 = x2 - k * x1;
         y2 = y2 - k * y1;
 
