@@ -59,7 +59,7 @@ PreparedPolygonContainsProperly::containsProperly(const geom::Geometry* geom)
     noding::SegmentStringUtil::extractSegmentStrings(geom, lineSegStr);
     bool segsIntersect = prepPoly->getIntersectionFinder()->intersects(&lineSegStr);
 
-    for(size_t i = 0, ni = lineSegStr.size(); i < ni; i++) {
+    for(std::size_t i = 0, ni = lineSegStr.size(); i < ni; i++) {
         delete lineSegStr[ i ];
     }
 
@@ -67,7 +67,7 @@ PreparedPolygonContainsProperly::containsProperly(const geom::Geometry* geom)
         return false;
     }
 
-    /**
+    /*
      * Given that no segments intersect, if any vertex of the target
      * is contained in some test component.
      * the test is NOT properly contained.
