@@ -38,7 +38,6 @@
 #define GEOS_DEBUG 1
 #endif
 
-//using namespace std;
 using namespace geos::geom;
 
 namespace geos {
@@ -131,7 +130,7 @@ DirectedEdgeStar::getRightmostEdge()
 
 /*public*/
 void
-DirectedEdgeStar::computeLabelling(std::vector<GeometryGraph*>* geom)
+DirectedEdgeStar::computeLabelling(const std::vector<std::unique_ptr<GeometryGraph>>&geom)
 //throw(TopologyException *)
 {
     // this call can throw a TopologyException
