@@ -52,6 +52,10 @@ GeoJSONWriter::setOutputDimension(uint8_t dims)
     defaultOutputDimension = dims;
 }
 
+void GeoJSONWriter::setForceCCW(bool newIsForceCCW) {
+    isForceCCW = newIsForceCCW;
+}
+
 std::string GeoJSONWriter::write(const geom::Geometry* geometry, GeoJSONType type)
 {
     json j;
@@ -109,15 +113,33 @@ void GeoJSONWriter::encodeGeoJSONValue(const std::string& key, const GeoJSONValu
         }
     }
     else if (value.isArray()) {
-        j[key] = json::array();
-        for (const GeoJSONValue& v : value.getArray()) {
-            encodeGeoJSONValue("", v, j[key]);
+        if (j.is_object()) {
+          j[key] = json::array();
+          for (const GeoJSONValue& v : value.getArray()) {
+              encodeGeoJSONValue("", v, j[key]);
+          }
+        }
+        else {
+          json sub_array = json::array();
+          for (const GeoJSONValue& v : value.getArray()) {
+              encodeGeoJSONValue("", v, sub_array);
+          }
+          j.push_back(sub_array);
         }
     }
     else if (value.isObject()) {
-        j[key] = json::object();
-        for (const auto& entry : value.getObject()) {
-            encodeGeoJSONValue(entry.first, entry.second, j[key]);
+        if (j.is_object()) {
+          j[key] = json::object();
+          for (const auto& entry : value.getObject()) {
+              encodeGeoJSONValue(entry.first, entry.second, j[key]);
+          }
+        }
+        else {
+          json sub_obj = json::object();
+          for (const auto& entry : value.getObject()) {
+              encodeGeoJSONValue(entry.first, entry.second, sub_obj);
+          }
+          j.push_back(sub_obj);
         }
     }
 }
@@ -205,7 +227,13 @@ void GeoJSONWriter::encodeGeometry(const geom::Geometry* geometry, geos_nlohmann
     }
     else if (type == GEOS_POLYGON) {
         auto poly = static_cast<const geom::Polygon*>(geometry);
-        encodePolygon(poly, j);
+        if (isForceCCW) {
+            auto ccwPoly = poly->clone();
+            ccwPoly->orientRings(false);
+            encodePolygon(ccwPoly.get(), j);
+        } else {
+            encodePolygon(poly, j);
+        }
     }
     else if (type == GEOS_MULTIPOINT) {
         auto multiPoint = static_cast<const geom::MultiPoint*>(geometry);
@@ -246,14 +274,7 @@ void GeoJSONWriter::encodeLineString(const geom::LineString* line, geos_nlohmann
 void GeoJSONWriter::encodePolygon(const geom::Polygon* poly, geos_nlohmann::ordered_json& j)
 {
     j["type"] = "Polygon";
-    std::vector<std::vector<std::vector<double>>> rings;
-    auto ring = poly->getExteriorRing();
-    rings.reserve(poly->getNumInteriorRing()+1);
-    rings.push_back(convertCoordinateSequence(ring->getCoordinates().get()));
-    for (size_t i = 0; i < poly->getNumInteriorRing(); i++) {
-        rings.push_back(convertCoordinateSequence(poly->getInteriorRingN(i)->getCoordinates().get()));
-    }
-    j["coordinates"] = rings;
+    j["coordinates"] = convertLinearRings(poly);
 }
 
 void GeoJSONWriter::encodeMultiPoint(const geom::MultiPoint* multiPoint, geos_nlohmann::ordered_json& j)
@@ -280,14 +301,13 @@ void GeoJSONWriter::encodeMultiPolygon(const geom::MultiPolygon* multiPolygon, g
     polygons.reserve(multiPolygon->getNumGeometries());
     for (size_t i = 0; i < multiPolygon->getNumGeometries(); i++) {
         const Polygon* polygon = multiPolygon->getGeometryN(i);
-        std::vector<std::vector<std::vector<double>>> rings;
-        auto ring = polygon->getExteriorRing();
-        rings.reserve(polygon->getNumInteriorRing() + 1);
-        rings.push_back(convertCoordinateSequence(ring->getCoordinates().get()));
-        for (size_t j = 0; j < polygon->getNumInteriorRing(); j++) {
-            rings.push_back(convertCoordinateSequence(polygon->getInteriorRingN(j)->getCoordinates().get()));
+        if (isForceCCW) {
+            auto ccwPolygon = polygon->clone();
+            ccwPolygon->orientRings(false);
+            polygons.push_back(convertLinearRings(ccwPolygon.get()));
+        } else {
+            polygons.push_back(convertLinearRings(polygon));
         }
-        polygons.push_back(rings);
     }
     json["coordinates"] = polygons;
 }
@@ -324,5 +344,17 @@ std::vector<std::vector<double>> GeoJSONWriter::convertCoordinateSequence(const
     return coordinates;
 }
 
+std::vector<std::vector<std::vector<double>>> GeoJSONWriter::convertLinearRings(const geom::Polygon* poly)
+{
+    std::vector<std::vector<std::vector<double>>> rings;
+    auto ring = poly->getExteriorRing();
+    rings.reserve(poly->getNumInteriorRing() + 1);
+    rings.push_back(convertCoordinateSequence(ring->getCoordinates().get()));
+    for (size_t i = 0; i < poly->getNumInteriorRing(); i++) {
+        rings.push_back(convertCoordinateSequence(poly->getInteriorRingN(i)->getCoordinates().get()));
+    }
+    return rings;
+}
+
 } // namespace geos.io
 } // namespace geos
