@@ -22,10 +22,10 @@
 #include <geos/operation/valid/MakeValid.h>
 #include <geos/operation/valid/IsValidOp.h>
 
-#include <geos/operation/overlay/OverlayOp.h>
+#include <geos/operation/overlayng/OverlayNG.h>
+#include <geos/operation/overlayng/OverlayNGRobust.h>
 #include <geos/operation/polygonize/BuildArea.h>
 #include <geos/operation/union/UnaryUnionOp.h>
-#include <geos/geom/HeuristicOverlay.h>
 #include <geos/geom/Geometry.h>
 #include <geos/geom/GeometryCollection.h>
 #include <geos/geom/GeometryFactory.h>
@@ -50,7 +50,8 @@
 #endif
 
 using namespace geos::geom;
-using namespace geos::operation::overlay;
+using geos::operation::overlayng::OverlayNG;
+using geos::operation::overlayng::OverlayNGRobust;
 
 namespace geos {
 namespace operation { // geos.operation
@@ -60,19 +61,19 @@ namespace valid { // geos.operation.valid
 static std::unique_ptr<geom::Geometry>
 makeValidSymDifference(const geom::Geometry* g0, const geom::Geometry* g1)
 {
-    return HeuristicOverlay(g0, g1, OverlayOp::opSYMDIFFERENCE);
+    return OverlayNGRobust::Overlay(g0, g1, OverlayNG::SYMDIFFERENCE);
 }
 
 static std::unique_ptr<geom::Geometry>
 makeValidDifference(const geom::Geometry* g0, const geom::Geometry* g1)
 {
-    return HeuristicOverlay(g0, g1, OverlayOp::opDIFFERENCE);
+    return OverlayNGRobust::Overlay(g0, g1, OverlayNG::DIFFERENCE);
 }
 
 static std::unique_ptr<geom::Geometry>
 makeValidUnion(const geom::Geometry* g0, const geom::Geometry* g1)
 {
-    return HeuristicOverlay(g0, g1, OverlayOp::opUNION);
+    return OverlayNGRobust::Overlay(g0, g1, OverlayNG::UNION);
 }
 
 /*
@@ -96,12 +97,10 @@ nodeLineWithFirstCoordinate(const geom::Geometry* geom)
 
   std::unique_ptr<geom::Geometry> point;
   if( geomType == GEOS_LINESTRING ) {
-      auto line = dynamic_cast<const geom::LineString*>(geom);
-      assert(line);
+      auto line = detail::down_cast<const geom::LineString*>(geom);
       point = line->getPointN(0);
   } else {
-      auto mls = dynamic_cast<const geom::MultiLineString*>(geom);
-      assert(mls);
+      auto mls = detail::down_cast<const geom::MultiLineString*>(geom);
       auto line = mls->getGeometryN(0);
       assert(line);
       point = line->getPointN(0);
@@ -122,8 +121,7 @@ static std::unique_ptr<geom::Geometry> MakeValidMultiLine(const geom::MultiLineS
     std::vector<std::unique_ptr<geom::Geometry>> lines;
 
     for(const auto& subgeom: *mls) {
-        auto line = dynamic_cast<const geom::LineString*>(subgeom.get());
-        assert(line);
+        auto line = detail::down_cast<const geom::LineString*>(subgeom.get());
         auto validSubGeom = MakeValidLine(line);
         if( !validSubGeom || validSubGeom->isEmpty() ) {
             continue;
@@ -135,7 +133,7 @@ static std::unique_ptr<geom::Geometry> MakeValidMultiLine(const geom::MultiLineS
         else if( validLineType == GEOS_LINESTRING ) {
             lines.emplace_back(std::move(validSubGeom));
         } else if( validLineType == GEOS_MULTILINESTRING ) {
-            auto mlsValid = dynamic_cast<const geom::MultiLineString*>(validSubGeom.get());
+            auto mlsValid = detail::down_cast<const geom::MultiLineString*>(validSubGeom.get());
             for(const auto& subgeomMlsValid: *mlsValid) {
                 lines.emplace_back(subgeomMlsValid->clone());
             }
@@ -240,7 +238,7 @@ static std::unique_ptr<geom::Geometry> MakeValidPoly(const geom::Geometry* geom)
         auto new_area = geos::operation::polygonize::BuildArea().build(cut_edges.get());
         assert(new_area); // never return nullptr, but exception
         if( new_area->isEmpty() ) {
-            /* no more rings can be build with thes edges */
+            /* no more rings can be built with these edges */
             break;
         }
 
@@ -316,11 +314,11 @@ std::unique_ptr<geom::Geometry> MakeValid::build(const geom::Geometry* geom)
 
     auto typeId = geom->getGeometryTypeId();
     if( typeId == GEOS_LINESTRING ) {
-        auto lineString = dynamic_cast<const LineString*>(geom);
+        auto lineString = detail::down_cast<const LineString*>(geom);
         return MakeValidLine(lineString);
     }
     if( typeId == GEOS_MULTILINESTRING ) {
-        auto mls = dynamic_cast<const MultiLineString*>(geom);
+        auto mls = detail::down_cast<const MultiLineString*>(geom);
         return MakeValidMultiLine(mls);
     }
     if( typeId == GEOS_POLYGON ||
@@ -328,7 +326,7 @@ std::unique_ptr<geom::Geometry> MakeValid::build(const geom::Geometry* geom)
         return MakeValidPoly(geom);
     }
     if( typeId == GEOS_GEOMETRYCOLLECTION ) {
-        auto coll = dynamic_cast<const GeometryCollection*>(geom);
+        auto coll = detail::down_cast<const GeometryCollection*>(geom);
         return MakeValidCollection(coll);
     }
 
