@@ -22,6 +22,7 @@
 #include <geos/triangulate/polygon/PolygonEarClipper.h>
 #include <geos/triangulate/polygon/TriDelaunayImprover.h>
 
+using namespace geos::geom;
 
 namespace geos {
 namespace triangulate {
@@ -39,8 +40,10 @@ ConstrainedDelaunayTriangulator::triangulate(const Geometry* geom)
 
 /* private */
 std::unique_ptr<Geometry>
-ConstrainedDelaunayTriangulator::compute()
+ConstrainedDelaunayTriangulator::compute() const
 {
+    util::ensureNoCurvedComponents(inputGeom);
+
     // short circuit empty input case
     if(inputGeom->isEmpty()) {
         auto gf = inputGeom->getFactory();
