@@ -70,8 +70,7 @@ struct test_area_data {
     void
     checkAreaOfRingSigned(std::string wkt, double expectedArea)
     {
-        std::unique_ptr<Geometry> lineGeom(reader_.read(wkt));
-        std::unique_ptr<LineString> line(dynamic_cast<LineString*>(lineGeom.release()));
+        auto line = reader_.read<LineString>(wkt);
         ensure(nullptr != line.get());
         const CoordinateSequence* ringSeq = line->getCoordinatesRO();
 
