@@ -8,9 +8,8 @@
 #include <geos/geom/PrecisionModel.h>
 #include <geos/geom/GeometryFactory.h>
 // std
-#include <cstdarg>
-#include <cstdio>
-#include <cstdlib>
+
+#include "capi_test_utils.h"
 
 namespace tut {
 //
@@ -18,38 +17,7 @@ namespace tut {
 //
 
 // Common data used in test cases.
-struct test_capigeoscontains_data {
-    GEOSGeometry* geom1_;
-    GEOSGeometry* geom2_;
-
-    static void
-    notice(const char* fmt, ...)
-    {
-        std::fprintf(stdout, "NOTICE: ");
-
-        va_list ap;
-        va_start(ap, fmt);
-        std::vfprintf(stdout, fmt, ap);
-        va_end(ap);
-
-        std::fprintf(stdout, "\n");
-    }
-
-    test_capigeoscontains_data()
-        : geom1_(nullptr), geom2_(nullptr)
-    {
-        initGEOS(notice, notice);
-    }
-
-    ~test_capigeoscontains_data()
-    {
-        GEOSGeom_destroy(geom1_);
-        GEOSGeom_destroy(geom2_);
-        geom1_ = nullptr;
-        geom2_ = nullptr;
-        finishGEOS();
-    }
-
+struct test_capigeoscontains_data : public capitest::utility {
 };
 
 typedef test_group<test_capigeoscontains_data> group;
@@ -66,18 +34,13 @@ template<>
 void object::test<1>
 ()
 {
-    geom1_ = GEOSGeomFromWKT("POLYGON EMPTY");
-    geom2_ = GEOSGeomFromWKT("POLYGON EMPTY");
-
-    ensure(nullptr != geom1_);
-    ensure(nullptr != geom2_);
+    geom1_ = fromWKT("POLYGON EMPTY");
+    geom2_ = fromWKT("POLYGON EMPTY");
 
     char const r1 = GEOSContains(geom1_, geom2_);
-
     ensure_equals(r1, 0);
 
     char const r2 = GEOSContains(geom2_, geom1_);
-
     ensure_equals(r2, 0);
 }
 
@@ -86,18 +49,13 @@ template<>
 void object::test<2>
 ()
 {
-    geom1_ = GEOSGeomFromWKT("POLYGON((1 1,1 5,5 5,5 1,1 1))");
-    geom2_ = GEOSGeomFromWKT("POINT(2 2)");
-
-    ensure(nullptr != geom1_);
-    ensure(nullptr != geom2_);
+    geom1_ = fromWKT("POLYGON((1 1,1 5,5 5,5 1,1 1))");
+    geom2_ = fromWKT("POINT(2 2)");
 
     char const r1 = GEOSContains(geom1_, geom2_);
-
     ensure_equals(int(r1), 1);
 
     char const r2 = GEOSContains(geom2_, geom1_);
-
     ensure_equals(int(r2), 0);
 }
 
@@ -106,18 +64,13 @@ template<>
 void object::test<3>
 ()
 {
-    geom1_ = GEOSGeomFromWKT("MULTIPOLYGON(((0 0,0 10,10 10,10 0,0 0)))");
-    geom2_ = GEOSGeomFromWKT("POLYGON((1 1,1 2,2 2,2 1,1 1))");
-
-    ensure(nullptr != geom1_);
-    ensure(nullptr != geom2_);
+    geom1_ = fromWKT("MULTIPOLYGON(((0 0,0 10,10 10,10 0,0 0)))");
+    geom2_ = fromWKT("POLYGON((1 1,1 2,2 2,2 1,1 1))");
 
     char const r1 = GEOSContains(geom1_, geom2_);
-
     ensure_equals(int(r1), 1);
 
     char const r2 = GEOSContains(geom2_, geom1_);
-
     ensure_equals(int(r2), 0);
 }
 
@@ -128,7 +81,7 @@ template<>
 void object::test<4>
 ()
 {
-    // Coincident vertives of both polygons at
+    // Coincident vertices of both polygons at
     // -700.67089999181 93743.4218587986, -713.450135807349 93754.1677576647,
     std::string const
     outer("01030000800100000009000000af9dd0005ee585c0f802efbff6e2f6400000000000000000955acde0994b86c039a922afa2e3f64000000000000000002af6fb4f5d1887c07adb1c4071e3f6400000000000000000e5962b388d4f87c0bd3aeda7bae2f640000000000000000087c61344030887c07d585e6ff6e1f6400000000000000000fc8a31b5166186c0230588b20ae1f640000000000000000034733daf050186c0ed9f3ac98ae1f6400000000000000000f190aef659b385c0df2876538ce2f6400000000000000000af9dd0005ee585c0f802efbff6e2f6400000000000000000");
@@ -235,5 +188,19 @@ void object::test<5>
     }
 }
 
+template<>
+template<>
+void object::test<6>()
+{
+    geom1_ = fromWKT("CIRCULARSTRING (0 0, 1 1, 2 0)");
+    geom2_ = fromWKT("LINESTRING (1 0, 2 0)");
+
+    ensure(geom1_);
+    ensure(geom2_);
+
+    ensure_equals("curved geometry not supported", GEOSContains(geom1_, geom2_), 2);
+}
+
+
 } // namespace tut
 
