@@ -20,24 +20,16 @@ template<>
 template<>
 void object::test<1>()
 {
-    GEOSGeometry* a = GEOSGeomFromWKT("LINESTRING (2 8, 10 8)");
-    GEOSGeometry* b = GEOSGeomFromWKT("LINESTRING (4 8, 6 8)");
+    geom1_ = fromWKT("LINESTRING (2 8, 10 8)");
+    geom2_ = fromWKT("LINESTRING (4 8, 6 8)");
 
-    ensure(a);
-    ensure(b);
+    GEOSSetSRID(geom1_, 4326);
 
-    GEOSSetSRID(a, 4326);
+    result_ = GEOSDifference(geom1_, geom2_);
+    ensure(result_);
 
-    GEOSGeometry* result = GEOSDifference(a, b);
-
-    ensure(result);
-
-    ensure_geometry_equals(result, "MULTILINESTRING ((6 8, 10 8), (2 8, 4 8))");
-    ensure_equals(GEOSGetSRID(a), GEOSGetSRID(result));
-
-    GEOSGeom_destroy(a);
-    GEOSGeom_destroy(b);
-    GEOSGeom_destroy(result);
+    ensure_geometry_equals(result_, "MULTILINESTRING ((6 8, 10 8), (2 8, 4 8))");
+    ensure_equals(GEOSGetSRID(geom1_), GEOSGetSRID(result_));
 }
 
 /**
@@ -45,8 +37,7 @@ void object::test<1>()
 */
 template<>
 template<>
-void object::test<2>()
-{
+void object::test<2>() {
     GEOSGeometry* a = GEOSGeomFromWKT("GEOMETRYCOLLECTION (POINT (51 -1), LINESTRING (52 -1, 49 2))");
     GEOSGeometry* b = GEOSGeomFromWKT("POINT (2 3)");
 
@@ -68,5 +59,19 @@ void object::test<2>()
     GEOSGeom_destroy(ba);
 }
 
+template<>
+template<>
+void object::test<3>()
+{
+    geom1_ = fromWKT("CIRCULARSTRING (0 0, 1 1, 2 0)");
+    geom2_ = fromWKT("LINESTRING (1 0, 2 1)");
+
+    ensure(geom1_);
+    ensure(geom2_);
+
+    result_ = GEOSDifference(geom1_, geom2_);
+    ensure("curved geometry not supported", result_ == nullptr);
+}
+
 } // namespace tut
 
