@@ -6,10 +6,7 @@
 #include <geos_c.h>
 // std
 #include <string>
-#include <cstdarg>
-#include <cstdio>
 #include <cstdlib>
-#include <memory>
 
 #include "capi_test_utils.h"
 
