@@ -30,5 +30,19 @@ void object::test<1>()
     GEOSFree(pattern);
 }
 
+template<>
+template<>
+void object::test<2>()
+{
+    geom1_ = fromWKT("CIRCULARSTRING (0 0, 1 1, 2 0)");
+    geom2_ = fromWKT("LINESTRING (1 0, 2 1)");
+
+    ensure(geom1_);
+    ensure(geom2_);
+
+    ensure("curved geometry not supported", GEOSRelate(geom1_, geom2_) == nullptr);
+    ensure("curved geometry not supported", GEOSRelate(geom2_, geom1_) == nullptr);
+}
+
 } // namespace tut
 
