@@ -4,11 +4,6 @@
 #include <tut/tut.hpp>
 // geos
 #include <geos_c.h>
-// std
-#include <cstdarg>
-#include <cstdio>
-#include <cstdlib>
-#include <memory>
 
 #include "capi_test_utils.h"
 
@@ -44,5 +39,16 @@ void object::test<1>
     ensure(0 != GEOSisEmpty(geom2_));
 }
 
+template<>
+template<>
+void object::test<2>()
+{
+    input_ = fromWKT("CIRCULARSTRING (0 0, 1 1, 2 0)");
+    ensure(input_ != nullptr);
+
+    result_ = GEOSSimplify(input_, 2);
+    ensure(result_ == nullptr);
+}
+
 } // namespace tut
 
