@@ -29,5 +29,19 @@ void object::test<1>()
     ensure_equals("MULTILINESTRING ((50 150, 50 200), (50 50, 50 100))", toWKT(geom3_));
 }
 
+template<>
+template<>
+void object::test<2>()
+{
+    geom1_ = fromWKT("CIRCULARSTRING (0 0, 1 1, 2 0)");
+    geom2_ = fromWKT("LINESTRING (1 0, 2 1)");
+
+    ensure(geom1_);
+    ensure(geom2_);
+
+    result_ = GEOSSymDifference(geom1_, geom2_);
+    ensure("curved geometry not supported", result_ == nullptr);
+}
+
 } // namespace tut
 
