@@ -1,14 +1,9 @@
 //
-// Test Suite for C-API GEOSSimplify
+// Test Suite for C-API GEOSGeom_setUserData
 
 #include <tut/tut.hpp>
 // geos
 #include <geos_c.h>
-// std
-#include <cstdarg>
-#include <cstdio>
-#include <cstdlib>
-#include <memory>
 
 #include "capi_test_utils.h"
 
