@@ -13,7 +13,6 @@
 #include <geos/geom/GeometryFactory.h>
 #include <geos/geom/PrecisionModel.h>
 #include <geos/io/WKTReader.h>
-#include <geos/io/WKTWriter.h>
 #include <geos/util/GEOSException.h>
 #include <geos/util/IllegalArgumentException.h>
 #include <geos/constants.h>
@@ -590,7 +589,6 @@ void object::test<32>
     ensure(!line_->hasDimension(geos::geom::Dimension::A));
 }
 
-
 // https://github.com/libgeos/geos/issues/1191
 // line->getPoint(n) loses M dimension
 template<>
@@ -598,15 +596,37 @@ template<>
 void object::test<33>
 ()
 {
-    auto geom = reader_.read("LINESTRING M (0 1 2, 10 11 12, 20 21 22)");
-    ensure(geom != nullptr);
-    geos::geom::LineString *line = static_cast<LineString*>(geom.get());
+    auto line = reader_.read<LineString>("LINESTRING M (0 1 2, 10 11 12, 20 21 22)");
     ensure_equals(line->getCoordinateDimension(), 3);
     auto pt = line->getPointN(2);
     auto out = writer_.write(*pt);
     ensure_equals(out, "POINT M (20 21 22)");
 }
 
+template<>
+template<>
+void object::test<34>
+()
+{
+    auto line = reader_.read<LineString>("LINESTRING Z (0 1 2, 10 11 12, 20 21 22)");
+    ensure_equals(line->getCoordinateDimension(), 3);
+    auto pt = line->getPointN(2);
+    auto out = writer_.write(*pt);
+    ensure_equals(out, "POINT Z (20 21 22)");
+}
+
+template<>
+template<>
+void object::test<35>
+()
+{
+    auto line = reader_.read<LineString>("LINESTRING ZM (0 1 2 3, 10 11 12 13, 20 21 22 23)");
+    ensure_equals(line->getCoordinateDimension(), 4);
+    auto pt = line->getPointN(2);
+    auto out = writer_.write(*pt);
+    ensure_equals(out, "POINT ZM (20 21 22 23)");
+}
+
 
 } // namespace tut
 
