@@ -12,11 +12,9 @@
 #include <geos/io/WKTWriter.h>
 #include <geos/index/VertexSequencePackedRtree.h>
 
-// std
-#include <stdio.h>
-
 using geos::index::VertexSequencePackedRtree;
-using geos::geom::Point;
+
+using namespace geos::geom;
 
 namespace tut {
 //
