@@ -13,7 +13,6 @@
 #include <geos/geom/GeometryCollection.h>
 #include <geos/geom/Coordinate.h>
 // std
-#include <sstream>
 #include <string>
 #include <memory>
 
@@ -34,7 +33,7 @@ struct test_geojsonreader_data {
         :
         pm(1000.0),
         gf(geos::geom::GeometryFactory::create(&pm)),
-        geojsonreader(*(gf.get()))
+        geojsonreader(*gf)
     {}
 
 };
