@@ -9,6 +9,7 @@
 #include <geos/util.h>
 
 // std
+#include <cfenv>
 #include <memory>
 
 using namespace geos::geom;
@@ -32,7 +33,9 @@ struct test_coverageunionng_data {
     {
         std::unique_ptr<Geometry> geom = r.read(wkt);
         std::unique_ptr<Geometry> expected = r.read(wktExpected);
+        std::feclearexcept(FE_ALL_EXCEPT);
         std::unique_ptr<Geometry> result = CoverageUnion::geomunion(geom.get());
+        ensure("FE_INVALID raised", !std::fetestexcept(FE_INVALID));
 
         try {
             ensure_equals_geometry_xyzm(result.get(), expected.get());
@@ -108,15 +111,6 @@ void object::test<5> ()
         "MULTIPOLYGON (((1 9, 6 9, 9 9, 9 1, 6 1, 1 1, 1 9), (2 8, 2 2, 6 2, 8 2, 8 8, 6 8, 2 8)), ((5 3, 3 3, 3 7, 5 7, 7 7, 7 3, 5 3), (5 4, 6 4, 6 6, 5 6, 4 6, 4 4, 5 4)))");
 }
 
-// testPolygonsNested
-template<>
-template<>
-void object::test<6> ()
-{
-    checkUnion(
-        "GEOMETRYCOLLECTION (POLYGON ((1 9, 9 9, 9 1, 1 1, 1 9), (3 7, 3 3, 7 3, 7 7, 3 7)), POLYGON ((3 7, 7 7, 7 3, 3 3, 3 7)))",
-        "POLYGON ((1 1, 1 9, 9 9, 9 1, 1 1))");
-}
 
 // testPolygonsFormingHole
 template<>
@@ -138,6 +132,16 @@ void object::test<8> ()
         "POLYGON ((0 25, 0 50, 0 75, 0 100, 25 100, 50 100, 75 100, 100 100, 100 75, 100 50, 100 25, 100 0, 75 0, 50 0, 25 0, 0 0, 0 25))");
 }
 
+// testPolygonsNested
+template<>
+template<>
+void object::test<6> ()
+{
+    checkUnion(
+        "GEOMETRYCOLLECTION (POLYGON ((1 9, 9 9, 9 1, 1 1, 1 9), (3 7, 3 3, 7 3, 7 7, 3 7)), POLYGON ((3 7, 7 7, 7 3, 3 3, 3 7)))",
+        "POLYGON ((1 1, 1 9, 9 9, 9 1, 1 1))");
+}
+
 /**
 * Sequential lines are still noded
 */
@@ -222,4 +226,66 @@ void object::test<17>()
                "POLYGON M ((0 0 0, 1 0 1, 1 1 2, 0 1 3, 0 0 0))");
 }
 
+// Check empty polygon
+template<>
+template<>
+void object::test<18>()
+{
+    checkUnion("POLYGON EMPTY",
+               "POLYGON EMPTY");
+}
+
+// Check empty GeometryCollection, with M dimension
+template<>
+template<>
+void object::test<19>()
+{
+    checkUnion("GEOMETRYCOLLECTION M EMPTY",
+               "GEOMETRYCOLLECTION M EMPTY");
+}
+
+// Check GeometryCollection of empty polygon
+template<>
+template<>
+void object::test<20>()
+{
+    checkUnion("GEOMETRYCOLLECTION( POLYGON EMPTY )",
+               "POLYGON EMPTY");
+}
+
+// testHoleTouchingSide
+template<>
+template<>
+void object::test<21> ()
+{
+    checkUnion(
+        "GEOMETRYCOLLECTION (POLYGON ((1 9, 9 9, 9 6, 2 6, 1 9)), POLYGON ((1 1, 1 9, 2 6, 5 3, 9 6, 9 1, 1 1)))",
+        "POLYGON ((9 6, 9 1, 1 1, 1 9, 9 9, 9 6), (9 6, 2 6, 5 3, 9 6))"
+    );
+}
+
+// testHolesTouchingSide
+template<>
+template<>
+void object::test<22> ()
+{
+    checkUnion(
+        "GEOMETRYCOLLECTION (POLYGON ((1 9, 9 9, 9 6, 5 7, 2 6, 1 9)), POLYGON ((1 1, 1 9, 2 6, 4 3, 5 7, 7 3, 9 6, 9 1, 1 1)))",
+        "POLYGON ((9 9, 9 6, 9 1, 1 1, 1 9, 9 9), (5 7, 7 3, 9 6, 5 7), (2 6, 4 3, 5 7, 2 6))"
+    );
+}
+
+// testHolesTouching
+template<>
+template<>
+void object::test<23> ()
+{
+    checkUnion(
+        "GEOMETRYCOLLECTION (POLYGON ((1 9, 9 9, 9 6, 7 7, 5 7, 2 6, 1 9)), POLYGON ((1 1, 1 9, 2 6, 4 3, 5 7, 7 3, 7 7, 9 6, 9 1, 1 1)))",
+        "POLYGON ((9 9, 9 6, 9 1, 1 1, 1 9, 9 9), (5 7, 7 3, 7 7, 5 7), (2 6, 4 3, 5 7, 2 6))"
+    );
+}
+
+
+
 } // namespace tut
