@@ -19,6 +19,7 @@
 #include <memory>
 
 using geos::geom::Coordinate;
+using geos::geom::CoordinateXY;
 using geos::geom::Geometry;
 using geos::geom::GeometryFactory;
 using geos::io::WKTReader;
@@ -63,10 +64,10 @@ struct test_overlayngrobust_data {
     std::unique_ptr<Geometry>
     double2geom(const std::vector<double>& x, const std::vector<double>& y)
     {
-        std::vector<geos::geom::Coordinate> coords;
+        auto coords = geos::detail::make_unique<CoordinateSequence>();
         for (std::size_t i = 0; i < x.size(); i++)
-            coords.emplace_back(x[i], y[i]);
-        std::unique_ptr<Geometry> geom = factory->createPolygon(std::move(coords));
+            coords->add(CoordinateXY{x[i], y[i]});
+        std::unique_ptr<Geometry> geom = factory->createPolygon(factory->createLinearRing(std::move(coords)));
         return geom;
     }
 
